@@ -7,12 +7,16 @@ import os.path as _path
 from pkg_resources import parse_version
 import structlog
 
+from . import conf_cacheable_with_name
+
 logger = structlog.get_logger(logger_name=__name__)
 _self_path = _path.dirname(_path.abspath(__file__))
 _cmd_prefix = ['/bin/bash', _path.join(_self_path, 'vcs.sh')]
 
 PROT_VER = 1
 
+get_cacheable_conf = conf_cacheable_with_name('vcs')
+
 def _parse_oldver(oldver):
     if oldver is None:
         return PROT_VER, 0, ''
@@ -27,7 +31,7 @@ def _parse_oldver(oldver):
     return PROT_VER, count, ver
 
 async def get_version(name, conf, **kwargs):
-  vcs = conf['vcs']
+  vcs = conf['vcs'] or ''
   use_max_tag = conf.getboolean('use_max_tag', False)
   ignored_tags = conf.get("ignored_tags", "").split()
   oldver = conf.get('oldver')
